SnapshotNode class
Represents a single node in the layout snapshot which can have nested children of the same type.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
SnapshotNode({bool highlighted = false, bool scrollable = false, String type = "container", required String label, required double x, required double y, required double width, required double height, required List<
SnapshotNode> children}) - Creates a new SnapshotNode.
Properties
-
children
→ List<
SnapshotNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- highlighted → bool
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollable → bool
-
final
- type → String
-
final
- width → double
-
final
- x → double
-
final
- y → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → SnapshotNode